<?php
/**
 * @version        1.6.1
 * @package        Joomla
 * @subpackage     Edocman
 * @author         Tuan Pham Ngoc
 * @copyright      Copyright (C) 2011 - 2014 Ossolution Team
 * @license        GNU/GPL, see LICENSE.php
 */

// No direct access.
defined('_JEXEC') or die;

class EDocmanModelCategory extends OSModelAdmin
{
	/**
	 * Method to get the form for the model.
	 *
	 * @param    array   $data     An optional array of data for the form.
	 * @param    boolean $loadData True if the form is to load its own data (default case), false if not.
	 *
	 * @return    JForm    A JForm object
	 */
	public function getForm($data = array(), $loadData = true)
	{
		$form = parent::getForm($data, $loadData);
		$form->setFieldAttribute('category_layout', 'directory', JPATH_ROOT . '/components/com_edocman/view/category/tmpl');

		return $form;
	}

	/**
	 * Store Category
	 *
	 * @param OSInput $input
	 *
	 * @return bool|void
	 * @throws Exception
	 */
	public function save($input)
	{
		// Initialise variables;
		$row  = $this->getTable();
		$data = $input->get('jform', array(), 'none');
		$id   = (int) $data['id'];
		// Delete old image if needed
		if ($id > 0)
		{
			$row->load($id);
			if ($input->has('del_image') && $row->image)
			{
				$categoryImagePath      = JPATH_ROOT . '/media/com_edocman/category/';
				$thumbCategoryImagePath = $categoryImagePath . 'thumbs/';
				if (JFile::exists($categoryImagePath . $row->image))
				{
					JFile::delete($categoryImagePath . $row->image);
				}
				if (JFile::exists($thumbCategoryImagePath . $row->image))
				{
					JFile::delete($thumbCategoryImagePath . $row->image);
				}
				$data['image'] = '';
			}
		}
		//Process image upload
		$files = $input->files->get('jform');
		$image = $files['image'];
		if (is_uploaded_file($image['tmp_name']))
		{
			if (!getimagesize($image['tmp_name']))
			{
				throw new Exception(JText::_('EDOCMAN_IMAGE_ERROR'));
			}
			$categoryImagePath      = JPATH_ROOT . '/media/com_edocman/category/';
			$thumbCategoryImagePath = $categoryImagePath . 'thumbs/';
			$fileName               = JFile::makeSafe($image['name']);
			if (JFile::upload($image['tmp_name'], $categoryImagePath . $fileName))
			{
				// Copy the file instead of resizing
				JFile::copy($categoryImagePath . $fileName, $thumbCategoryImagePath . $fileName);
				$data['image'] = $fileName;
			}
		}

		//For Save As copy, if no thumbnail image uploaded, we just use thumbnail from original record
		if ($input->get('task') == 'save2copy' && empty($data['image']))
		{
			$originalCategory = clone $row;
			$originalCategory->load($input->getInt('id'));
			$data['image'] = $originalCategory->image;
		}

		//Store the modified jform data back to input object for processing in parent class
		$input->set('jform', $data);

		parent::save($input);
	}

	/**
	 *
	 * Prepare the category data, before saving record to database
	 *
	 * @param JTable $row
	 * @param string $task
	 * @param array  $data
	 */
	protected function prepareTable($row, $task, $data = array())
	{
		if ($row->path)
		{
			$config    = EdocmanHelper::getConfig();
			$path      = str_replace("\\", "/", $row->path);
			$path      = JString::strtolower($path);
			$path      = JFolder::makeSafe($path);
			$row->path = $path;
			$path      = $config->documents_path . '/' . $row->path;
			if (!JFolder::exists($path))
			{
				JFolder::create($path);
			}
		}

		parent::prepareTable($row, $task, $data);
	}

	/**
	 * A protected method to get a set of ordering conditions.
	 *
	 * @param JTable A record object.
	 *
	 * @return array  An array of conditions to add to add to ordering queries.
	 */
	protected function getReorderConditions($table)
	{
		$condition   = array();
		$condition[] = ' parent_id = ' . (int) $table->parent_id;

		return $condition;
	}

	/**
	 * Method to check if the current user can delete the record
	 *
	 * @param EDocmanTableCategory $row
	 *
	 * @return boolean
	 */

	protected function canDelete($row)
	{
		if (!empty($row->id))
		{
			return JFactory::getUser()->authorise('core.delete', 'com_edocman.category.' . (int) $row->id);
		}
		else
		{
			return parent::canDelete($row);
		}
	}

	/**
	 * Method to check if the current user can change status of the record
	 *
	 * @see OSModelForm::canEditState()
	 */
	protected function canEditState($row)
	{
		if (!empty($row->id))
		{
			return JFactory::getUser()->authorise('core.edit.state', 'com_edocman.category.' . (int) $row->id);
		}
		else
		{
			return parent::canEditState($row);
		}
	}
}